@@ -28,14 +28,13 @@ proc xcircuit::getsubckttext {name} {
 	 if {$ltype == "info"} {
 	    set itext [label $j text]
 	    if {[string first ".subckt" $itext] >= 0} {
-	       break;
+   	       if {$curhandle != $handle} {symbol goto}
+	       return $itext
 	    }
 	 }
       }
    }
-
-   if {$curhandle != $handle} {symbol goto}
-   return $itext
+   return ""
 }
 
 #---------------------------------------------------------------------------
@@ -56,6 +55,8 @@ proc xcircuit::getsubckttext {name} {
 proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
    global XCOps
 
+   config suspend true	;# suspend graphics and change count
+
    set techname [.dialog.techself.techselect cget -text]
    set symbolname [.dialog.textent.txt get]
 
@@ -195,7 +196,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
    element $nlab color set blue
 
    deselect selected
-   parameter make substring idx "?"
+   parameter make substring index "?"
    parameter make substring class "X"
    if {$schematicname == $symbolname} {
       parameter make substring link "%n"
@@ -203,7 +204,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       parameter make substring link "$schematicname"
    }
 
-   set nlab [label make "{Parameter class} {Parameter idx}" "0 -$pinspace"]
+   set nlab [label make "{Parameter class} {Parameter index}" "0 -$pinspace"]
    label $nlab justify center
    element $nlab color set blue
    deselect selected
@@ -243,7 +244,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
          symbol goto
       }
 
-      set itext [list {Text "spice:"} {Parameter class} {Parameter idx}]
+      set itext [list {Text "spice:"} {Parameter class} {Parameter index}]
       set pstring ""
       foreach j $pinlabels {
 	 if {[string length $pstring] > 60} {
@@ -256,7 +257,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       set pstring [join [list $pstring "%n"]]   ;# preserves whitespace
       lappend itext [subst {Text "$pstring"}]
    } else {
-      set itext [list {Text "spice:"} {Parameter class} {Parameter idx}]
+      set itext [list {Text "spice:"} {Parameter class} {Parameter index}]
       set pstring ""
       foreach j [lrange [lindex $subckttext 0] 2 end] {
 	 if {[string length $pstring] > 60} {
@@ -294,6 +295,8 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       symbol goto
       zoom view
    }
+
+   config suspend false 	;# unlocked state
 }
 
 #---------------------------------------------------------------------------
